@@ -84,7 +84,7 @@ CopyGameToClipboard()
     return;
   }
   if (!SaveGame(f,0,"")) { 			/* call into backend */
-    DisplayError("Cannot reopen temporary file.", 0);
+    DisplayError("Cannot write to temporary file.", 0);
     goto copy_game_to_clipboard_cleanup;
   }
   f = fopen(copyTemp, "rb");
@@ -112,9 +112,6 @@ CopyGameToClipboard()
     DisplayError("Cannot read from temporary file.", 0);
     goto copy_game_to_clipboard_cleanup;
   }
-#if 1
-  fprintf(debugFP, "CopyGameToClipboard(): size %ld, len %u\n", size, len);
-#endif
   if ((unsigned long)size != (unsigned long)len) { /* sigh */ 
       DisplayError("Error reading from temporary file.", 0);
       goto copy_game_to_clipboard_cleanup;
