@@ -200,13 +200,13 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       appData.blindfold            = IS_CHECKED(OPT_Blindfold);
       appData.highlightDragging    = IS_CHECKED(OPT_HighlightDragging);
       appData.highlightLastMove    = IS_CHECKED(OPT_HighlightLastMove);
-      appData.periodicUpdates      = IS_CHECKED(OPT_PeriodicUpdates);
-      appData.ponderNextMove       = IS_CHECKED(OPT_PonderNextMove);
+      PeriodicUpdatesEvent(          IS_CHECKED(OPT_PeriodicUpdates));
+      PonderNextMoveEvent(           IS_CHECKED(OPT_PonderNextMove));
       appData.popupExitMessage     = IS_CHECKED(OPT_PopupExitMessage);
       appData.popupMoveErrors      = IS_CHECKED(OPT_PopupMoveErrors);
       appData.showButtonBar        = IS_CHECKED(OPT_ShowButtonBar);
       appData.showCoords           = IS_CHECKED(OPT_ShowCoordinates);
-      appData.showThinking         = IS_CHECKED(OPT_ShowThinking);
+      ShowThinkingEvent(             IS_CHECKED(OPT_ShowThinking));
       appData.testLegality         = IS_CHECKED(OPT_TestLegality);
 
 #undef IS_CHECKED
@@ -223,9 +223,6 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 	ClearHighlights();
 	DrawPosition(FALSE, NULL);
       }
-      PeriodicUpdatesEvent(appData.periodicUpdates);
-      PonderNextMoveEvent(appData.ponderNextMove);
-      ShowThinkingEvent(appData.showThinking);
       /* 
        * for some reason the redraw seems smoother when we invalidate
        * the board rect after the call to EndDialog()
